@@ -2,7 +2,9 @@ from soda.execution.query.query import Query
 
 
 class SampleQuery(Query):
-    def __init__(self, data_source_scan: "DataSourceScan", metric: "Metric", sample_type: str, sql: str):
+    def __init__(
+        self, data_source_scan: "DataSourceScan", metric: "Metric", sample_type: str, sql: str, passing_sql: str
+    ):
         """
         :param sample_type: Eg 'failed_rows'
         """
@@ -13,6 +15,7 @@ class SampleQuery(Query):
             unqualified_query_name=f"{sample_type}[{metric.name}]",
             sql=sql,
             samples_limit=metric.samples_limit,
+            passing_sql=passing_sql,
         )
         self.metric = metric
 
