@@ -7,7 +7,6 @@ import textwrap
 from datetime import datetime, timezone
 
 from soda.__version__ import SODA_CORE_VERSION
-from soda.common.attributes_handler import AttributeHandler
 from soda.common.json_helper import JsonHelper
 from soda.common.log import Log, LogLevel
 from soda.common.logs import Logs
@@ -24,6 +23,7 @@ from soda.sampler.default_sampler import DefaultSampler
 from soda.sampler.sampler import Sampler
 from soda.soda_cloud.historic_descriptor import HistoricDescriptor
 from soda.soda_cloud.soda_cloud import SodaCloud
+from soda.sodacl.check_cfg import CheckCfg
 from soda.sodacl.location import Location
 from soda.sodacl.sodacl_cfg import SodaCLCfg
 from soda.telemetry.soda_telemetry import SodaTelemetry
@@ -59,6 +59,7 @@ class Scan:
         self._data_source_manager = DataSourceManager(self._logs, self._configuration)
         self._data_source_scans: list[DataSourceScan] = []
         self._metrics: set[Metric] = set()
+        self._checks_configs: list[CheckCfg] = []
         self._checks: list[Check] = []
         self._queries: list[Query] = []
         self._profile_columns_result_tables: list[ProfileColumnsResultTable] = []
@@ -429,69 +430,85 @@ class Scan:
                                                 column_metrics.column,
                                             )
 
-            # Each data_source is asked to create metric values that are returned as a list of query results
-            for data_source_scan in self._data_source_scans:
-                data_source_scan.execute_queries()
-
-            # Compute derived metric values
-            for metric in self._metrics:
-                if isinstance(metric, DerivedMetric):
-                    metric.compute_derived_metric_values()
-
-            # Run profiling, data samples, automated monitoring, sample tables
-            try:
-                self.run_data_source_scan()
-            except Exception as e:
-                self._logs.error(f"""An error occurred while executing data source scan""", exception=e)
-
-            # Evaluates the checks based on all the metric values
+            # Handle check attributes before proceeding.
+            invalid_check_attributes = None
+            invalid_checks = []
             for check in self._checks:
-                # First get the metric values for this check
-                check_metrics = {}
-                missing_value_metrics = []
-                for check_metric_name, metric in check.metrics.items():
-                    if metric.value is not undefined:
-                        check_metrics[check_metric_name] = metric
-                    else:
-                        missing_value_metrics.append(metric)
-
-                check_historic_data = {}
-                # For each check get the historic data
-                if check.historic_descriptors:
-                    for hd_key, hd in check.historic_descriptors.items():
-                        check_historic_data[hd_key] = self.__get_historic_data_from_soda_cloud_metric_store(hd)
-
-                if not missing_value_metrics:
-                    try:
-                        check.evaluate(check_metrics, check_historic_data)
-                    except BaseException as e:
-                        self._logs.error(
-                            f"Evaluation of check {check.check_cfg.source_line} failed: {e}",
-                            location=check.check_cfg.location,
-                            exception=e,
-                        )
-                else:
-                    missing_metrics_str = ",".join([str(metric) for metric in missing_value_metrics])
-                    self._logs.error(
-                        f"Metrics '{missing_metrics_str}' were not computed for check '{check.check_cfg.source_line}'"
-                    )
-
-                # Validate check attributes as well.
                 if check.check_cfg.source_configurations:
+                    check_attributes = {
+                        self.jinja_resolve(k): self.jinja_resolve(v)
+                        for k, v in check.check_cfg.source_configurations.get("attributes", {}).items()
+                    }
+
                     if self._configuration.soda_cloud:
-                        attributes = check.check_cfg.source_configurations.get("attributes", {})
-                        attribute_handler = AttributeHandler(self._logs)
-                        self._logs.info("Validating check attributes.")
-                        # TODO: get attributes schema from Cloud Configuration when it is supported by cloud.
-                        # attributes_schema = self._configuration.soda_cloud.get_check_attributes_schema()
-                        attributes_schema = {}
+                        # Validate attributes if Cloud is available
+                        if check_attributes:
+                            from soda.common.attributes_handler import AttributeHandler
 
-                        attributes, invalid_attributes = attribute_handler.validate(attributes, attributes_schema)
+                            attribute_handler = AttributeHandler(self._logs)
+                            attributes_schema = self._configuration.soda_cloud.get_check_attributes_schema()
 
-                        if invalid_attributes:
-                            self._logs.debug(f"Skipping invalid attributes '{invalid_attributes.keys()}'.")
+                            check_attributes, invalid_check_attributes = attribute_handler.validate(
+                                check_attributes, attributes_schema
+                            )
 
-                        check.attributes = attributes
+                            # Skip (remove) the check if invalid attributes are present.
+                            if invalid_check_attributes:
+                                invalid_checks.append(check)
+
+                    check.attributes = check_attributes
+
+            if invalid_check_attributes:
+                attributes_page_url = f"https://{self._configuration.soda_cloud.host}/organization/attributes"
+                self._logs.info(f"Refer to list of valid attributes and values at {attributes_page_url}.")
+
+            if not invalid_checks:
+                # Each data_source is asked to create metric values that are returned as a list of query results
+                for data_source_scan in self._data_source_scans:
+                    data_source_scan.execute_queries()
+
+                # Compute derived metric values
+                for metric in self._metrics:
+                    if isinstance(metric, DerivedMetric):
+                        metric.compute_derived_metric_values()
+
+                # Run profiling, data samples, automated monitoring, sample tables
+                try:
+                    self.run_data_source_scan()
+                except Exception as e:
+                    self._logs.error(f"""An error occurred while executing data source scan""", exception=e)
+
+                # Evaluates the checks based on all the metric values
+                for check in self._checks:
+                    # First get the metric values for this check
+                    check_metrics = {}
+                    missing_value_metrics = []
+                    for check_metric_name, metric in check.metrics.items():
+                        if metric.value is not undefined:
+                            check_metrics[check_metric_name] = metric
+                        else:
+                            missing_value_metrics.append(metric)
+
+                    check_historic_data = {}
+                    # For each check get the historic data
+                    if check.historic_descriptors:
+                        for hd_key, hd in check.historic_descriptors.items():
+                            check_historic_data[hd_key] = self.__get_historic_data_from_soda_cloud_metric_store(hd)
+
+                    if not missing_value_metrics:
+                        try:
+                            check.evaluate(check_metrics, check_historic_data)
+                        except BaseException as e:
+                            self._logs.error(
+                                f"Evaluation of check {check.check_cfg.source_line} failed: {e}",
+                                location=check.check_cfg.location,
+                                exception=e,
+                            )
+                    else:
+                        missing_metrics_str = ",".join([str(metric) for metric in missing_value_metrics])
+                        self._logs.error(
+                            f"Metrics '{missing_metrics_str}' were not computed for check '{check.check_cfg.source_line}'"
+                        )
 
             self._logs.info("Scan summary:")
             self.__log_queries(having_exception=False)
@@ -508,7 +525,7 @@ class Scan:
             checks_not_evaluated = len(self._checks) - checks_pass_count - checks_warn_count - checks_fail_count
 
             if len(self._checks) == 0:
-                self._logs.warning("No checks found, 0 checks evaluated.")
+                self._logs.warning("No valid checks found, 0 checks evaluated.")
             if checks_not_evaluated:
                 self._logs.info(f"{checks_not_evaluated} checks not evaluated.")
             if error_count > 0:
@@ -585,12 +602,6 @@ class Scan:
                 "metrics_count": len(self._metrics),
             }
         )
-        if self._configuration.soda_cloud:
-            for (
-                request_name,
-                trace_id,
-            ) in self._configuration.soda_cloud.soda_cloud_trace_ids.items():
-                soda_telemetry.set_attribute(f"soda_cloud_trace_id__{request_name}", trace_id)
 
         return exit_value
 
